@@ -14,6 +14,8 @@ from reVX.utilities.exclusions_converter import ExclusionsConverter
 from reVX.utilities.forecasts import Forecasts
 from reVX.utilities.output_extractor import output_extractor
 from reVX.utilities.region import RegionClassifier
+from reVX.wind_setbacks.setbacks_converter import SetbacksConverter
+
 from reVX import __version__
 
 logger = logging.getLogger(__name__)
@@ -135,12 +137,14 @@ def exclusions(ctx, excl_h5):
 
 @exclusions.command()
 @click.option('--layers', '-l', required=True, type=click.Path(exists=True),
-              help=(".json file containing list of geotiffs to load or "
-                    "mapping of layer names to geotiffs"))
-@click.option('--descriptions', '-d', default=None,
-              type=click.Path(exists=True), show_default=True,
-              help=(".json file containing layer descriptions as a list or "
-                    "mapping to layers"))
+              help=(".json file containing mapping of layer names to geotiffs."
+                    " Json can also contain layer descriptions and/or "
+                    "scale factors"))
+@click.option('-check_tiff', '-ct', is_flag=True,
+              help=("Flag to check tiff profile and coordinates against "
+                    "exclusion .h5 profile and coordinates"))
+@click.option('-setbacks', '-sb', is_flag=True,
+              help=("Flag to convert setbacks to exclusion layers"))
 @click.option('--transform_atol', '-tatol', default=0.01, type=float,
               show_default=True,
               help=("Absolute tolerance parameter when comparing geotiff "
@@ -153,7 +157,8 @@ def exclusions(ctx, excl_h5):
 @click.option('--purge', '-r', is_flag=True,
               help="Remove existing .h5 file before loading layers")
 @click.pass_context
-def layers_to_h5(ctx, layers, descriptions, transform_atol, coord_atol, purge):
+def layers_to_h5(ctx, layers, check_tiff, setbacks, transform_atol, coord_atol,
+                 purge):
     """
     Add layers to exclusions .h5 file
     """
@@ -161,20 +166,25 @@ def layers_to_h5(ctx, layers, descriptions, transform_atol, coord_atol, purge):
     if purge and os.path.isfile(excl_h5):
         os.remove(excl_h5)
 
-    layers = safe_json_load(layers)
-    if 'layers' in layers:
-        layers = layers['layers']
+    inputs = safe_json_load(layers)
+    layers = inputs['layers']
+    descriptions = inputs.get('descriptions')
+    scale_factors = inputs.get('scale_factors')
 
-    if descriptions is not None:
-        descriptions = safe_json_load(descriptions)
-        if 'descriptions' in descriptions:
-            descriptions = {os.path.basename(layer).split('.')[0]: d
-                            for layer, d in zip(layers, descriptions)}
-
-    ExclusionsConverter.layers_to_h5(excl_h5, layers,
-                                     transform_atol=transform_atol,
-                                     coord_atol=coord_atol,
-                                     descriptions=descriptions)
+    if setbacks:
+        SetbacksConverter.layers_to_h5(excl_h5, layers,
+                                       check_tiff=check_tiff,
+                                       transform_atol=transform_atol,
+                                       coord_atol=coord_atol,
+                                       descriptions=descriptions,
+                                       scale_factors=scale_factors)
+    else:
+        ExclusionsConverter.layers_to_h5(excl_h5, layers,
+                                         check_tiff=check_tiff,
+                                         transform_atol=transform_atol,
+                                         coord_atol=coord_atol,
+                                         descriptions=descriptions,
+                                         scale_factors=scale_factors)
 
 
 @exclusions.command()
