@@ -157,7 +157,7 @@ def local(ctx, out_dir, log_dir, verbose):
     if 'VERBOSE' in ctx.obj:
         verbose = any((ctx.obj['VERBOSE'], verbose))
 
-    log_modules = ['reVX', 'reV', 'rex']
+    log_modules = [__name__, 'reVX', 'reV', 'rex']
     init_mult(name, log_dir, modules=log_modules, verbose=verbose)
 
     logger.info('Running reV to ReEDS pipeline\n'
@@ -460,8 +460,8 @@ def eagle(config):
                 'node name "{}"'.format(name))
     slurm_manager = SLURM()
     out = slurm_manager.sbatch(cmd,
-                               alloc=config.execution_control.alloc,
-                               memory=config.execution_control.node_mem,
+                               alloc=config.execution_control.allocation,
+                               memory=config.execution_control.memory,
                                walltime=config.execution_control.walltime,
                                feature=config.execution_control.feature,
                                name=name, stdout_path=stdout_path,
