@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=all
 """
-ReEDS Command Line Interface
+Wind Setbacks CLI
 """
-
 import click
+from copy import deepcopy
 import logging
 import os
 
@@ -23,24 +23,26 @@ from reVX import __version__
 logger = logging.getLogger(__name__)
 
 
+STATE_SETBACKS = {'structure': StructureWindSetbacks,
+                  'road': RoadWindSetbacks,
+                  'rail': RailWindSetbacks,
+                  'tranmission': TransmissionWindSetbacks}
+
+
 @click.group()
 @click.option('--name', '-n', default='WindSetbacks', type=STR,
               show_default=True,
               help='Job name. Default is "WindSetbaks".')
-@click.option('--log_dir', '-log', default=None, type=STR, show_default=True,
-              help='Directory to dump log files. Default is out_dir.')
 @click.option('--verbose', '-v', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
-def main(ctx, name, log_dir, verbose):
+def main(ctx, name, verbose):
     """
     Wind Setbacks Command Line Interface
     """
     ctx.ensure_object(dict)
     ctx.obj['NAME'] = name
-
-    log_modules = ['reVX', 'reV', 'rex']
-    init_mult(name, log_dir, modules=log_modules, verbose=verbose)
+    ctx.obj['VERBOSE'] = verbose
 
 
 @main.command()
@@ -59,31 +61,6 @@ def valid_config_keys():
     click.echo(', '.join(get_class_properties(WindSetbacksConfig)))
 
 
-def run_local(ctx, config):
-    """
-    Run Wind Setbacks locally from config
-
-    Parameters
-    ----------
-    ctx : click.ctx
-        click ctx object
-    config : reVX.config.wind_setbacks.WindSetbacks
-        Wind Setbacks config object.
-    """
-    ctx.obj['NAME'] = config.name
-    ctx.invoke(local,
-               excl_h5=config.excl_h5,
-               features_path=config.features_path,
-               layer_name=config.layer_name,
-               hub_height=config.hub_height,
-               rotor_diameter=config.rotor_diameter,
-               regs_fpath=config.regs_fpath,
-               multiplier=config.multiplier,
-               max_workers=config.max_workers,
-               description=config.description,
-               replace=config.replace)
-
-
 @main.command()
 @click.option('--config', '-c', required=True,
               type=click.Path(exists=True),
@@ -109,12 +86,14 @@ def from_config(ctx, config):
                     'be the location of any new setback layers'))
 @click.option('--features_path', '-feats', required=True,
               type=click.Path(exists=True),
-              help=('Path to directory containing state level structure or '
-                    'road features files, or path to transmission or railroad '
-                    'CONUS wide features'))
-@click.option('--layer_name', '-layer', required=True, type=str,
-              help=('Name of new layer to write to exclusions .h5 file '
-                    'containing computed setbacks'))
+              help=('Path to:/n'
+                    '- State level structure .geotiff or directory containing '
+                    'geotiff files./n'
+                    '- State level roads .gdb or directory containing .gdb '
+                    'files./n'
+                    '-transmission or railroad CONUS wide .shp file.'))
+@click.option('--out_dir', '-o', required=True, type=str,
+              help=('Directory to save setbacks geotiff(s) into'))
 @click.option('--hub_height', '-height', required=True, type=float,
               help=('Turbine hub height(m), used along with rotor diameter to '
                     'compute blade tip height which is used to determine '
@@ -141,29 +120,40 @@ def from_config(ctx, config):
                     'run in serial, if > 1 run in parallel with that many '
                     'workers, if None run in parallel on all available cores, '
                     'by default None'))
-@click.option('--description', '-desc', default=None, type=STR,
-              show_default=True,
-              help=('Description of exclusion layer(set as an attribute), '
-                    'by default None'))
 @click.option('--replace', '-r', is_flag=True,
               help=('Flag to replace local layer data with arr if layer '
                     'already exists in the exlcusion .h5 file'))
+@click.option('--hsds', '-hsds', is_flag=True,
+              help=('Flag to use h5pyd to handle .h5 domain hosted on AWS '
+                    'behind HSDS'))
+@click.option('--log_dir', '-log', default=None, type=STR,
+              show_default=True,
+              help='Directory to dump log files. Default is out_dir.')
+@click.option('--verbose', '-v', is_flag=True,
+              help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
-def local(ctx, excl_h5, features_path, layer_name, hub_height, rotor_diameter,
-          regs_fpath, multiplier, max_workers, description, replace):
+def local(ctx, excl_h5, features_path, out_dir, hub_height, rotor_diameter,
+          regs_fpath, multiplier, max_workers, replace, hsds, log_dir,
+          verbose):
     """
     Compute Wind Setbacks locally
     """
     ctx.obj['EXCL_H5'] = excl_h5
     ctx.obj['FEATURES_PATH'] = features_path
-    ctx.obj['LAYER_NAME'] = layer_name
+    ctx.obj['OUT_DIR'] = out_dir
     ctx.obj['HUB_HEIGHT'] = hub_height
     ctx.obj['ROTOR_DIAMETER'] = rotor_diameter
     ctx.obj['REGS_FPATH'] = regs_fpath
     ctx.obj['MULTIPLIER'] = multiplier
     ctx.obj['MAX_WORKERS'] = max_workers
-    ctx.obj['DESCRIPTION'] = description
     ctx.obj['REPLACE'] = replace
+    ctx.obj['HSDS'] = hsds
+
+    if 'VERBOSE' in ctx.obj:
+        verbose = any((ctx.obj['VERBOSE'], verbose))
+
+    log_modules = [__name__, 'reVX', 'reV', 'rex']
+    init_mult(ctx.obj['NAME'], log_dir, modules=log_modules, verbose=verbose)
 
 
 @local.command()
@@ -174,14 +164,14 @@ def structure_setbacks(ctx):
     """
     excl_h5 = ctx.obj['EXCL_H5']
     features_path = ctx.obj['FEATURES_PATH']
-    layer_name = ctx.obj['LAYER_NAME']
+    out_dir = ctx.obj['OUT_DIR']
     hub_height = ctx.obj['HUB_HEIGHT']
     rotor_diameter = ctx.obj['ROTOR_DIAMETER']
     regs_fpath = ctx.obj['REGS_FPATH']
     multiplier = ctx.obj['MULTIPLIER']
     max_workers = ctx.obj['MAX_WORKERS']
-    description = ctx.obj['DESCRIPTION']
     replace = ctx.obj['REPLACE']
+    hsds = ctx.obj['HSDS']
 
     logger.info('Computing setbacks from structures in {}'
                 .format(features_path))
@@ -195,12 +185,12 @@ def structure_setbacks(ctx):
                  .format(hub_height, rotor_diameter, regs_fpath, multiplier,
                          max_workers, replace))
 
-    StructureWindSetbacks.run(excl_h5, features_path, layer_name, hub_height,
+    StructureWindSetbacks.run(excl_h5, features_path, out_dir, hub_height,
                               rotor_diameter, regs_fpath=regs_fpath,
                               multiplier=multiplier, max_workers=max_workers,
-                              description=description, replace=replace)
+                              replace=replace, hsds=hsds)
     logger.info('Setbacks computed and writen to {} as {}'
-                .format(excl_h5, layer_name))
+                .format(excl_h5, out_dir))
 
 
 @local.command()
@@ -211,14 +201,14 @@ def road_setbacks(ctx):
     """
     excl_h5 = ctx.obj['EXCL_H5']
     features_path = ctx.obj['FEATURES_PATH']
-    layer_name = ctx.obj['LAYER_NAME']
+    out_dir = ctx.obj['OUT_DIR']
     hub_height = ctx.obj['HUB_HEIGHT']
     rotor_diameter = ctx.obj['ROTOR_DIAMETER']
     regs_fpath = ctx.obj['REGS_FPATH']
     multiplier = ctx.obj['MULTIPLIER']
     max_workers = ctx.obj['MAX_WORKERS']
-    description = ctx.obj['DESCRIPTION']
     replace = ctx.obj['REPLACE']
+    hsds = ctx.obj['HSDS']
 
     logger.info('Computing setbacks from roads in {}'
                 .format(features_path))
@@ -232,12 +222,12 @@ def road_setbacks(ctx):
                  .format(hub_height, rotor_diameter, regs_fpath, multiplier,
                          max_workers, replace))
 
-    RoadWindSetbacks.run(excl_h5, features_path, layer_name, hub_height,
+    RoadWindSetbacks.run(excl_h5, features_path, out_dir, hub_height,
                          rotor_diameter, regs_fpath=regs_fpath,
                          multiplier=multiplier, max_workers=max_workers,
-                         description=description, replace=replace)
+                         replace=replace, hsds=hsds)
     logger.info('Setbacks computed and writen to {} as {}'
-                .format(excl_h5, layer_name))
+                .format(excl_h5, out_dir))
 
 
 @local.command()
@@ -248,14 +238,14 @@ def transmission_setbacks(ctx):
     """
     excl_h5 = ctx.obj['EXCL_H5']
     features_path = ctx.obj['FEATURES_PATH']
-    layer_name = ctx.obj['LAYER_NAME']
+    out_dir = ctx.obj['OUT_DIR']
     hub_height = ctx.obj['HUB_HEIGHT']
     rotor_diameter = ctx.obj['ROTOR_DIAMETER']
     regs_fpath = ctx.obj['REGS_FPATH']
     multiplier = ctx.obj['MULTIPLIER']
     max_workers = ctx.obj['MAX_WORKERS']
-    description = ctx.obj['DESCRIPTION']
     replace = ctx.obj['REPLACE']
+    hsds = ctx.obj['HSDS']
 
     logger.info('Computing setbacks from transmission in {}'
                 .format(features_path))
@@ -269,13 +259,13 @@ def transmission_setbacks(ctx):
                  .format(hub_height, rotor_diameter, regs_fpath, multiplier,
                          max_workers, replace))
 
-    TransmissionWindSetbacks.run(excl_h5, features_path, layer_name,
-                                 hub_height, rotor_diameter,
-                                 regs_fpath=regs_fpath, multiplier=multiplier,
-                                 max_workers=max_workers,
-                                 description=description, replace=replace)
+    TransmissionWindSetbacks.run(excl_h5, features_path, out_dir, hub_height,
+                                 rotor_diameter, regs_fpath=regs_fpath,
+                                 multiplier=multiplier,
+                                 max_workers=max_workers, replace=replace,
+                                 hsds=hsds)
     logger.info('Setbacks computed and writen to {} as {}'
-                .format(excl_h5, layer_name))
+                .format(excl_h5, out_dir))
 
 
 @local.command()
@@ -286,14 +276,14 @@ def rail_setbacks(ctx):
     """
     excl_h5 = ctx.obj['EXCL_H5']
     features_path = ctx.obj['FEATURES_PATH']
-    layer_name = ctx.obj['LAYER_NAME']
+    out_dir = ctx.obj['OUT_DIR']
     hub_height = ctx.obj['HUB_HEIGHT']
     rotor_diameter = ctx.obj['ROTOR_DIAMETER']
     regs_fpath = ctx.obj['REGS_FPATH']
     multiplier = ctx.obj['MULTIPLIER']
     max_workers = ctx.obj['MAX_WORKERS']
-    description = ctx.obj['DESCRIPTION']
     replace = ctx.obj['REPLACE']
+    hsds = ctx.obj['HSDS']
 
     logger.info('Computing setbacks from structures in {}'
                 .format(features_path))
@@ -307,15 +297,52 @@ def rail_setbacks(ctx):
                  .format(hub_height, rotor_diameter, regs_fpath, multiplier,
                          max_workers, replace))
 
-    RailWindSetbacks.run(excl_h5, features_path, layer_name, hub_height,
+    RailWindSetbacks.run(excl_h5, features_path, out_dir, hub_height,
                          rotor_diameter, regs_fpath=regs_fpath,
                          multiplier=multiplier, max_workers=max_workers,
-                         description=description, replace=replace)
+                         replace=replace, hsds=hsds)
     logger.info('Setbacks computed and writen to {} as {}'
-                .format(excl_h5, layer_name))
+                .format(excl_h5, out_dir))
 
 
-def get_node_cmd(config):
+def run_local(ctx, config):
+    """
+    Run Wind Setbacks locally from config
+
+    Parameters
+    ----------
+    ctx : click.ctx
+        click ctx object
+    config : reVX.config.wind_setbacks.WindSetbacks
+        Wind Setbacks config object.
+    """
+    ctx.obj['NAME'] = config.name
+    ctx.invoke(local,
+               excl_h5=config.excl_h5,
+               features_path=config.features_path,
+               out_dir=config.dirout,
+               hub_height=config.hub_height,
+               rotor_diameter=config.rotor_diameter,
+               regs_fpath=config.regs_fpath,
+               multiplier=config.multiplier,
+               max_workers=config.max_workers,
+               replace=config.replace)
+
+    feature_type = config.feature_type
+    if feature_type == 'structure':
+        ctx.invoke(structure_setbacks)
+    elif feature_type == 'road':
+        ctx.invoke(road_setbacks)
+    elif feature_type == 'transmission':
+        ctx.invoke(transmission_setbacks)
+    elif feature_type == 'rail':
+        ctx.invoke(rail_setbacks)
+    else:
+        msg = 'Feature type must be one of {}'.format(config.FEATURE_TYPES)
+        raise RuntimeError(msg)
+
+
+def get_node_cmd(name, config):
     """
     Get the node CLI call for the Wind Setbacks computation
 
@@ -329,23 +356,25 @@ def get_node_cmd(config):
     cmd : str
         CLI call to submit to SLURM execution.
     """
-    args = ['-n {}'.format(SLURM.s(config.name)),
-            '-log {}'.format(SLURM.s(config.logdir)),
+    args = ['-n {}'.format(SLURM.s(name)),
             'local',
             '-excl {}'.format(SLURM.s(config.excl_h5)),
             '-feats {}'.format(SLURM.s(config.features_path)),
-            '-layer {}'.format(SLURM.s(config.layer_name)),
+            '-o {}'.format(SLURM.s(config.dirout)),
             '-height {}'.format(SLURM.s(config.hub_height)),
             '-diameter {}'.format(SLURM.s(config.rotor_diameter)),
             '-regs {}'.format(SLURM.s(config.regs_fpath)),
             '-mult {}'.format(SLURM.s(config.multiplier)),
             '-mw {}'.format(SLURM.s(config.max_workers)),
-            '-desc {}'.format(SLURM.s(config.description)),
+            '-log {}'.format(SLURM.s(config.logdir)),
             ]
 
     if config.replace:
         args.append('-r')
 
+    if config.hsds:
+        args.append('-hsds')
+
     if config.log_level == logging.DEBUG:
         args.append('-v')
 
@@ -369,29 +398,31 @@ def get_node_cmd(config):
     return cmd
 
 
-def eagle(config):
+def launch_job(config):
     """
-    Run Wind Setbacks on Eagle HPC.
+    Launch job from config on SLURM
 
     Parameters
     ----------
     config : reVX.config.wind_setbacks.WindSetbacks
         Wind Setbacks config object.
     """
-    cmd = get_node_cmd(config)
-    name = config.name
     log_dir = config.logdir
     stdout_path = os.path.join(log_dir, 'stdout/')
+    name = os.path.basename(config.features_path).split('.')[0]
+    name = "{}-{}".format(config.name, name)
+    cmd = get_node_cmd(name, config)
 
     logger.info('Computing Wind Setbacks on Eagle with '
                 'node name "{}"'.format(name))
     slurm_manager = SLURM()
     out = slurm_manager.sbatch(cmd,
-                               alloc=config.execution_control.alloc,
-                               memory=config.execution_control.node_mem,
+                               alloc=config.execution_control.allocation,
+                               memory=config.execution_control.memory,
                                walltime=config.execution_control.walltime,
                                feature=config.execution_control.feature,
-                               name=name, stdout_path=stdout_path,
+                               name=name,
+                               stdout_path=stdout_path,
                                conda_env=config.execution_control.conda_env,
                                module=config.execution_control.module)[0]
     if out:
@@ -407,6 +438,30 @@ def eagle(config):
     logger.info(msg)
 
 
+def eagle(config):
+    """
+    Run Wind Setbacks on Eagle HPC.
+
+    Parameters
+    ----------
+    config : reVX.config.wind_setbacks.WindSetbacks
+        Wind Setbacks config object.
+    """
+    features_path = config.features_path
+    cls = STATE_SETBACKS[config.feature_type]
+    features = cls._get_feature_paths(features_path)
+    if not features:
+        msg = ('No valid feature files were found at {}!'
+               .format(features_path))
+        logger.error(msg)
+        raise FileNotFoundError(msg)
+
+    for fpath in features:
+        fpath_config = deepcopy(config)
+        fpath_config['features_path'] = fpath
+        launch_job(fpath_config)
+
+
 if __name__ == '__main__':
     try:
         main(obj={})
